/*==============================================================*/
/* Database name:  axyl                                         */
/* DBMS name:      Microsoft SQL Server 7.x                     */
/* Created on:     15/02/2005 8:03:18 a.m.                      */
/*==============================================================*/


if exists (select 1
          from sysobjects
          where  id = object_id('modstamp')
          and type = 'P')
   drop procedure modstamp
go



CREATE FUNCTION "modstamp" () RETURNS opaque AS 'BEGIN NEW.last_modified := CURRENT_TIMESTAMP; RETURN NEW; END; '
LANGUAGE 'plpgsql';
go



create trigger ax_block_modstamp before update on ax_block
   for each row execute procedure modstamp();


create trigger ax_forum_msg_modstamp before update on ax_forum_msg
   for each row execute procedure modstamp();


create trigger ax_layout_modstamp before update on ax_layout
   for each row execute procedure modstamp();


create trigger ax_menu_modstamp before update on ax_menu
   for each row execute procedure modstamp();


create trigger ax_menuoption_modstamp before update on ax_menuoption
   for each row execute procedure modstamp();


create trigger ax_microsite_modstamp before update on ax_microsite
   for each row execute procedure modstamp();


create trigger ax_story_modstamp before update on ax_story
   for each row execute procedure modstamp();

